==> apache-camel-2.25.1-src.zip: apache-camel-2.25.1/components/camel-spring/src/test/java/org/apache/camel/spring/config/ErrorHandlerConfigTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.config;

import org.apache.camel.CamelContext;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.spring.SpringRunWithTestSupport;
import org.junit.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;

/**
 * @version 
 */
@ContextConfiguration
public class ErrorHandlerConfigTest extends SpringRunWithTestSupport {

    @Autowired
    protected ProducerTemplate template;

    @Autowired
    protected CamelContext context;

    protected Object expectedBody = "<hello>world!</hello>";

    @Test
    public void testRouteInheritsConfiguredErrorHandler() throws Exception {
        assertReceivedMessageWithErrorHandlerValue("defaultErrorHandler", "defaultErrorHandler");
    }

    @Test
    public void testRouteConfiguredErrorHandler() throws Exception {
        assertReceivedMessageWithErrorHandlerValue("customErrorHandler", "customErrorHandler");
    }

    protected void assertReceivedMessageWithErrorHandlerValue(String name, String value) throws InterruptedException {
        template.sendBody("direct:" + name, expectedBody);

        MockEndpoint endpoint = MockEndpoint.resolve(context, "mock:" + name);
        endpoint.expectedMessageCount(1);
        endpoint.message(0).header(DummyErrorHandlerBuilder.PROPERTY_NAME).isEqualTo(value);
        endpoint.assertIsSatisfied();
    }
}

==> apache-camel-3.4.5-src.zip: apache-camel-3.4.5/components/camel-spring/src/test/java/org/apache/camel/spring/config/ErrorHandlerConfigTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.spring.config;

import org.apache.camel.CamelContext;
import org.apache.camel.ProducerTemplate;
import org.apache.camel.component.mock.MockEndpoint;
import org.apache.camel.spring.SpringRunWithTestSupport;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.test.context.ContextConfiguration;

@ContextConfiguration
public class ErrorHandlerConfigTest extends SpringRunWithTestSupport {

    @Autowired
    protected ProducerTemplate template;

    @Autowired
    protected CamelContext context;

    protected Object expectedBody = "<hello>world!</hello>";

    @Test
    public void testRouteInheritsConfiguredErrorHandler() throws Exception {
        assertReceivedMessageWithErrorHandlerValue("defaultErrorHandler", "defaultErrorHandler");
    }

    @Test
    public void testRouteConfiguredErrorHandler() throws Exception {
        assertReceivedMessageWithErrorHandlerValue("customErrorHandler", "customErrorHandler");
    }

    protected void assertReceivedMessageWithErrorHandlerValue(String name, String value) throws InterruptedException {
        template.sendBody("direct:" + name, expectedBody);

        MockEndpoint endpoint = MockEndpoint.resolve(context, "mock:" + name);
        endpoint.expectedMessageCount(1);
        endpoint.message(0).header(DummyErrorHandlerBuilder.PROPERTY_NAME).isEqualTo(value);
        endpoint.assertIsSatisfied();
    }
}
